@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "overleaf" "1.1.4"
+(define-package "overleaf" "20250728.2103"
   "Sync and track changes live with overleaf."
   '((emacs     "29.4")
     (plz       "0.9")
